@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2015-03-19'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -72,6 +72,8 @@ sub _fmt_opt {
                 if ($parsed->{type}) {
                     if ($spec->{'x.schema.entity'}) {
                         $opt .= "=".$spec->{'x.schema.entity'};
+                    } elsif ($spec->{'x.schema.element_entity'}) {
+                        $opt .= "=".$spec->{'x.schema.element_entity'};
                     } else {
                         $opt .= "=$parsed->{type}";
                     }
@@ -257,7 +259,7 @@ sub gen_cli_doc_data_from_meta {
                         summary => $rimeta->langprop({lang=>$lang}, 'summary') //
                             "Alias for "._dash_prefix($ospec->{parsed}{opts}[0]),
                         description =>
-                        $rimeta->langprop({lang=>$lang}, 'description'),
+                            $rimeta->langprop({lang=>$lang}, 'description'),
                     };
                 } else {
                     # an option for argument
@@ -291,7 +293,7 @@ sub gen_cli_doc_data_from_meta {
                         # --opt, show singular version of summary if available.
                         # otherwise show regular summary.
                         $opt->{summary} =
-                            $rimeta->langprop({lang=>$lang}, 'summary.alt.numnoun.singular') //
+                            $rimeta->langprop({lang=>$lang}, 'summary.alt.plurality.singular') //
                                 $rimeta->langprop({lang=>$lang}, 'summary');
                     } else {
                         $opt->{summary} =
@@ -361,6 +363,8 @@ sub gen_cli_doc_data_from_meta {
                         $rimeta->langprop({lang=>$lang}, 'summary.alt.bool.not') :
                             $rimeta->langprop({lang=>$lang}, 'summary'),
                     (schema => $spec->{schema}) x !!$spec->{schema},
+                    ('x.schema.entity' => $spec->{'x.schema.entity'}) x !!$spec->{'x.schema.entity'},
+                    ('x.schema.element_entity' => $spec->{'x.schema.element_entity'}) x !!$spec->{'x.schema.element_entity'},
                     description =>
                         $rimeta->langprop({lang=>$lang}, 'description'),
                     (default => $spec->{default}) x !!(exists($spec->{default}) && !$show_neg),
@@ -455,7 +459,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.15 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-03-19.
+This document describes version 0.16 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
